<?php
/**
 * PayForLink extension for the phpBB >=3.2.0 Forum Software package.
 * @copyright (c) 2017 Picaron
 * @license GNU General Public License, version 2 (GPL-2.0)
 */

namespace Picaron\PayForLink\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class listener implements EventSubscriberInterface
{
    /** @var \phpbb\user */
    protected $user;

    /** @var \phpbb\template\template */
    protected $template;

    /**
    * Constructor
    *
    * @param \phpbb\user                        $user
    * @param \phpbb\template\template           $template
    *
    */
    public function __construct(
        \phpbb\user $user,
        \phpbb\template\template $template
    )
    {
        $this->user         = $user;
        $this->template     = $template;
    }

    static public function getSubscribedEvents()
    {
        return array(
            'core.user_setup'                   => 'load_language_on_setup',
            'core.posting_modify_template_vars' => 'posting_modify_template_vars',
            'core.acp_board_config_edit_add'    => 'acp_board_config_edit_add',
        );
    }

    // Load Lenguage
    public function load_language_on_setup($event)
    {
        $lang_set_ext = $event['lang_set_ext'];
        $lang_set_ext[] = array(
            'ext_name' => 'Picaron/PayForLink',
            'lang_set' => 'payforlink',
        );
        $event['lang_set_ext'] = $lang_set_ext;
    }

    //  Display Review
    public function posting_modify_template_vars($event)
    {
        global $config;

        $this->template->assign_vars(array(
            'PAYFORLINK_VERSION' => $config['version_payforlink'],
        ));
    }

    // ACP
    public function acp_board_config_edit_add($event)
    {
        if ($event['mode'] == 'post')
        {
            $display_vars = $event['display_vars'];
            $add_config_var = array(
                'legend65' => 'ACP_PAYFORLINK_SETTINGS',
                'display_payforlink_show' => array('lang' => 'DISPLAY_PAYFORLINK_SHOW', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => false),
                'display_payforlink_cant' => array('lang' => 'DISPLAY_PAYFORLINK_CANT', 'validate' => 'int:5:100', 'type' => 'number:0:99999', 'explain' => false),
            );
            $display_vars['vars'] = phpbb_insert_config_array($display_vars['vars'], $add_config_var, array('after' =>'allow_quick_reply'));
            $event['display_vars'] = array('title' => $display_vars['title'], 'vars' => $display_vars['vars']);
        }
    }

}
?>